Compose — bodhi 4.0.0 documentation

# Compose

## Python objects

Message schema for Composes.

Each message is defined as a Python class. For details, see fedora-messaging documentation on messages.

class `bodhi.messages.schemas.compose.` `ComposeCompleteV1`(body=None, headers=None, topic=None, properties=None, severity=None)

  Bases: `bodhi.messages.schemas.base.BodhiMessage`

  Sent when a compose task completes.

  `repo`

    Return the name of the repository being composed.

  `success`

    Return the name of the repository being composed.

  `summary`

    Return a short, human-readable representation of this message.

    This should provide a short summary of the message, much like the subject line of an email.

    Returns: | The message summary.

  `topic` = 'bodhi.compose.complete'

class `bodhi.messages.schemas.compose.` `ComposeComposingV1`(body=None, headers=None, topic=None, properties=None, severity=None)

  Bases: `bodhi.messages.schemas.base.BodhiMessage`

  Sent when the compose task composes.

  `repo`

    Return the name of the repository being composed.

  `summary`

    Return a short, human-readable representation of this message.

    This should provide a short summary of the message, much like the subject line of an email.

    Returns: | A summary for this message.

  `topic` = 'bodhi.compose.composing'

class `bodhi.messages.schemas.compose.` `ComposeStartV1`(body=None, headers=None, topic=None, properties=None, severity=None)

  Bases: `bodhi.messages.schemas.base.BodhiMessage`

  Sent when a compose task starts.

  `summary`

    Return a short, human-readable representation of this message.

    This should provide a short summary of the message, much like the subject line of an email.

    Returns: | A summary for this message.

  `topic` = 'bodhi.compose.start'

class `bodhi.messages.schemas.compose.` `ComposeSyncDoneV1`(body=None, headers=None, topic=None, properties=None, severity=None)

  Bases: `bodhi.messages.schemas.base.BodhiMessage`

  Sent when a compose task sync is done.

  `repo`

    Return the name of the repository being composed.

  `summary`

    Return a short, human-readable representation of this message.

    This should provide a short summary of the message, much like the subject line of an email.

    Returns: | A summary for this message.

  `topic` = 'bodhi.compose.sync.done'

class `bodhi.messages.schemas.compose.` `ComposeSyncWaitV1`(body=None, headers=None, topic=None, properties=None, severity=None)

  Bases: `bodhi.messages.schemas.base.BodhiMessage`

  Sent when a compose task sync is waiting.

  `repo`

    Return the name of the repository being composed.

  `summary`

    Return a short, human-readable representation of this message.

    This should provide a short summary of the message, much like the subject line of an email.

    Returns: | A summary for this message.

  `topic` = 'bodhi.compose.sync.wait'

## JSON schemas

### bodhi.compose.complete

    {
        "id": "https://bodhi.fedoraproject.org/message-schemas/v1/bodhi.compose.complete#",
        "$schema": "http://json-schema.org/draft-04/schema#",
        "description": "Schema for message sent when composes finish",
        "type": "object",
        "properties": {
            "agent": {
                "type": "string",
                "description": "The name of the user who started this compose."
            },
            "repo": {
                "type": "string",
                "description": "The name of the repository being composed."
            },
            "success": {
                "type": "boolean",
                "description": "true if the compose was successful, false otherwise."
            }
        },
        "required": [
            "agent",
            "repo",
            "success"
        ]
    }

### bodhi.compose.composing

    {
        "id": "https://bodhi.fedoraproject.org/message-schemas/v1/bodhi.compose.composing#",
        "$schema": "http://json-schema.org/draft-04/schema#",
        "description": "Schema for message sent when composes start",
        "type": "object",
        "properties": {
            "agent": {
                "type": "string",
                "description": "The name of the user who started this compose."
            },
            "repo": {
                "type": "string",
                "description": "The name of the repository being composed."
            }
        },
        "required": [
            "agent",
            "repo"
        ]
    }

### bodhi.compose.start

    {
        "id": "https://bodhi.fedoraproject.org/message-schemas/v1/bodhi.compose.start#",
        "$schema": "http://json-schema.org/draft-04/schema#",
        "description": "Schema for message sent when composes start",
        "type": "object",
        "properties": {
            "agent": {
                "type": "string",
                "description": "The name of the user who started this compose."
            }
        },
        "required": [
            "agent"
        ]
    }

### bodhi.compose.sync.done

    {
        "id": "https://bodhi.fedoraproject.org/message-schemas/v1/bodhi.compose.sync.done#",
        "$schema": "http://json-schema.org/draft-04/schema#",
        "description": "Schema for message sent when the composer is done waiting to sync to mirrors",
        "type": "object",
        "properties": {
            "agent": {
                "type": "string",
                "description": "The name of the user who started this compose."
            },
            "repo": {
                "type": "string",
                "description": "The name of the repository being composed."
            }
        },
        "required": [
            "agent",
            "repo"
        ]
    }

### bodhi.compose.sync.wait

    {
        "id": "https://bodhi.fedoraproject.org/message-schemas/v1/bodhi.compose.sync.wait#",
        "$schema": "http://json-schema.org/draft-04/schema#",
        "description": "Schema for message sent when the composer is waiting to sync to mirrors",
        "type": "object",
        "properties": {
            "agent": {
                "type": "string",
                "description": "The name of the user who started this compose."
            },
            "repo": {
                "type": "string",
                "description": "The name of the repository being composed."
            }
        },
        "required": [
            "agent",
            "repo"
        ]
    }